import BlurFade from "@/components/ui/blur-fade";
import { MagicCard } from "@/components/ui/magic-card";
import NumberTicker from "@/components/ui/number-ticker";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { Icon } from "@iconify/react/dist/iconify.js";
import { Check } from "lucide-react";
import { getTranslations } from "next-intl/server";
import Image from "next/image";

async function Packages({
	locale,
	packages,
}: {
	locale: Locale;
	packages: any[];
}) {
	const t = await getTranslations("Services");

	const _packages = packages?.map((ele: any, index: number) => ({
		id: ele.id,
		recommended: index === 1,
		title: {
			ar: ele.name_ar,
			en: ele.name_en,
		},
		price: parseFloat(ele.price),
		description: {
			ar: ele.description_ar,
			en: ele.description_en,
		},
		visits: ele?.visits,
		visits_type: ele?.visits_type,
		features: ele.features?.map((item: any) => ({
			id: item.id,
			ar: item.text.ar,
			en: item.text.en,
		})),
	}));

	return (
		<section className="flex flex-col items-center justify-center mt-32 px-3 md:px-12">
			<p className="text-nowrap text-3xl leading-7 text-custom-primary-accent md:text-4xl md:leading-10">
				الباقات
			</p>
			<p className="mt-8 text-justify text-base text-[#616161]">
				{t("PackageDescription")}
			</p>

			<div className="mt-16 flex w-full flex-wrap items-center justify-center gap-10 md:flex-nowrap">
				{_packages?.map((element: any, index: number) => (
					<BlurFade
						key={element.id}
						duration={1.5}
						delay={index * 0.3}
						inView
						direction={"up"}
						className="w-[22rem]"
					>
						<MagicCard
							backgroundColor={
								element.recommended ? "bg-[#606676]" : "bg-white"
							}
							gradientColor={"#D9D9D955"}
							key={element.id}
							className="group rounded-xl relative flex-[30.333%] overflow-hidden"
							style={{
								border: "1px solid #DEDEDE",
								zIndex: 100,
								boxShadow: "0px 0px 10px 0px rgba(0, 0, 0, 0.1)",
							}}
							cardClassName="w-[22rem]"
						>
							{element.recommended && (
								<div className="flex h-[36px] items-center justify-center bg-[#000000B2] text-white">
									{t("MostRequested")}
								</div>
							)}
							<div className="flex flex-col items-center gap-4 p-6">
								<p
									className={cn(
										"text-lg",
										element.recommended
											? "text-white"
											: "text-custom-primary-accent"
									)}
								>
									{element.title?.[locale]}
								</p>
								<p
									className={cn(
										"flex items-end gap-2 text-4xl",
										element.recommended ? "text-white" : "text-[#606676]"
									)}
								>
									<NumberTicker
										value={element.price}
										className={cn(
											"text-[#606676]",
											element.recommended ? "text-white" : ""
										)}
									/>{" "}
									<Image
										src={"/coins/Saudi_Riyal.jpg"}
										alt="Saudi_Riyal"
										width={20}
										height={12}
										className="mb-2"
									/>

								</p>
								<div
									className={cn(
										"flex gap-8",
										element.recommended ? "text-white" : "text-[#606676]"
									)}
								>
									<div className="flex gap-1">
										<Icon icon={"weui:location-filled"} className="mt-[4px]" width={20} height={20} />
										<span className="text-md">{element?.visits}</span>
									</div>

									<div className="flex gap-1">
										<Icon icon={"solar:calendar-linear"} className="mt-[4px]" width={20} height={20} />
										<span className="text-md">{t(element?.visits_type)}</span>
									</div>

								</div>
								<p
									className={cn(
										"text-center text-[12px] leading-[24px]",
										element.recommended ? "text-white" : "text-[#606676]"
									)}
								>
									{element.description?.[locale]}
								</p>
							</div>

							{/* المزايا */}
							<div className="relative z-10 flex flex-col items-center gap-2">
								<div className="flex min-w-[300px] flex-col gap-2 p-14">
									{element.features?.map((feature: any) => (
										<p
											key={feature.id}
											className={cn(
												"z-10 flex items-center gap-3 text-base font-normal",
												element.recommended ? "text-white" : "text-[#646464]"
											)}
										>
											<Check
												size={16}
												strokeWidth={5}
												className={cn(
													"text-custom-primary-accent",
													element.recommended ? "text-white" : ""
												)}
											/>
											{feature?.[locale]}
										</p>
									))}
								</div>

								<div
									className={cn(
										"absolute bottom-0 left-1/2 z-0 h-[calc(85%-2px)] w-[calc(100%-2px)] -translate-x-1/2",
										element.recommended ? "bg-[#2895C8]" : "bg-[#F6F7FB]"
									)}
								/>
							</div>

							<div className="relative flex h-[56px] items-center justify-center">
								<button className="relative z-10 w-full text-base text-white">
									{t("BuyService")}
								</button>
								<div
									className={cn(
										"absolute bottom-0 left-1/2 z-0 h-[calc(100%-2px)] w-[calc(100%-2px)] -translate-x-1/2",
										element.recommended
											? "bg-[#606676]"
											: "bg-custom-primary-accent"
									)}
								/>
							</div>
						</MagicCard>
					</BlurFade>
				))}
			</div>
		</section>
	);
}

export default Packages;
